@@ -237,6 +237,7 @@ ctpl_token_expr_new_value (const CtplValue *value)
   token = ctpl_token_expr_new ();
   if (token) {
     token->type = CTPL_TOKEN_EXPR_TYPE_VALUE;
+    ctpl_value_init (&token->token.t_value);
     ctpl_value_copy (value, &token->token.t_value);
   }
   
@@ -300,8 +301,11 @@ ctpl_token_expr_free_full (CtplTokenExpr *token,
         break;
     }
     while (token->indexes) {
+      GSList *next = token->indexes->next;
+      
       ctpl_token_expr_free (token->indexes->data);
-      token->indexes = token->indexes->next;
+      g_slist_free_1 (token->indexes);
+      token->indexes = next;
     }
     g_slice_free1 (sizeof *token, token);
   }
